Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMarek Safar <marek.safar@gmail.com>2004-12-14 10:45:28 +0300
committerMarek Safar <marek.safar@gmail.com>2004-12-14 10:45:28 +0300
commit4a9765f6d3f2436a975f4376c19f448bd54a45cf (patch)
treedb96b251408a672315a205e978a6583c0a916d25 /mcs/errors/cs0502.cs
parent38f846b3d05eef240c2e2a46acbea9a3e35e6fe4 (diff)
2004-12-14 Marek Safar <marek.safar@seznam.cz>
* cs0418-2.cs, cs0418.cs, cs0441.cs, cs0662.cs cs0724.cs, cs1004.cs, cs1521-2.cs, cs1521.cs, cs1558.cs, cs1576.cs, cs3017.cs, cs3018-2.cs, cs3018.cs, cs3021.cs, cs3022.cs, cs3023.cs, cs3025.cs: New error tests. svn path=/trunk/mcs/; revision=37729
Diffstat (limited to 'mcs/errors/cs0502.cs')
-rw-r--r--mcs/errors/cs0502.cs12
1 files changed, 9 insertions, 3 deletions
diff --git a/mcs/errors/cs0502.cs b/mcs/errors/cs0502.cs
index b589cba2f75..1a578596c8b 100644
--- a/mcs/errors/cs0502.cs
+++ b/mcs/errors/cs0502.cs
@@ -1,5 +1,11 @@
-// cs0502.cs: 'Sample' cannot be both abstract and sealed
-// Line: 4
+// cs0502.cs: 'Main.Test()' cannot be both abstract and sealed
+// Line: 10
-abstract sealed class Sample {
+abstract class Base {
+ public abstract void Test () {}
+}
+
+abstract class Main: Base
+{
+ public abstract sealed override void Test () {}
}